import { DrawCommand } from "regl";
import { CoordinateSystem } from "./coordinates/coordinate-system";
export declare type UnpackPromise<T> = T extends Promise<infer U> ? U : never;
export interface Viewport {
    x: number;
    y: number;
    width: number;
    height: number;
}
export declare enum RenderableType {
    Primitive = 0,
    Composite = 1
}
export declare abstract class Primitive {
    /** @internal */
    readonly kind = RenderableType.Primitive;
    /** @internal */
    abstract command(glsl: string): DrawCommand;
    /** @internal */
    abstract render(command: DrawCommand): void;
    /** Releases all GPU resources and renders this instance unusable. */
    abstract dispose(): void;
}
export declare abstract class Composite {
    /** @internal */
    readonly kind = RenderableType.Composite;
    /** @internal */
    abstract children(): Renderable;
    /** @internal */
    readonly scope: DrawCommand | null;
    /** @internal */
    props(coords: CoordinateSystem): {};
    /** Releases all GPU resources and renders this instance unusable. Also disposes any children. */
    dispose(): void;
}
export declare type Renderable = Primitive | Composite | Renderable[];
export declare type NumberArray = number[] | Float32Array;
export declare type Vector2 = number[] | Float32Array;
export declare type Vector3 = number[] | Float32Array;
export declare type Vector4 = number[] | Float32Array;
