export var RenderableType;
(function (RenderableType) {
    RenderableType[RenderableType["Primitive"] = 0] = "Primitive";
    RenderableType[RenderableType["Composite"] = 1] = "Composite";
})(RenderableType || (RenderableType = {}));
export class Primitive {
    constructor() {
        /** @internal */
        this.kind = RenderableType.Primitive;
    }
}
export class Composite {
    constructor() {
        /** @internal */
        this.kind = RenderableType.Composite;
        /** @internal */
        this.scope = null;
    }
    /** @internal */
    props(coords) {
        return {};
    }
    /** Releases all GPU resources and renders this instance unusable. Also disposes any children. */
    dispose() {
        function recurse(renderable) {
            if (Array.isArray(renderable)) {
                for (const element of renderable) {
                    recurse(element);
                }
            }
            else if (renderable.kind === RenderableType.Composite) {
                recurse(renderable.children());
            }
            else if (renderable.kind === RenderableType.Primitive) {
                renderable.dispose();
            }
        }
        recurse(this.children());
    }
}
//# sourceMappingURL=common.js.map